@@ -550,6 +550,8 @@ class FakeHTTPClient(base_client.HTTPClient):
             _body = body
         elif action == 'revert':
             assert 'snapshot_id' in body[action]
+        elif action == 'os-reimage':
+            assert 'image_id' in body[action]
         else:
             raise AssertionError("Unexpected action: %s" % action)
         return (resp, {}, _body)
